==> download.php?loc=extern&filen=kb5010_SwyxItClientSDK_11.25.zip: Samples/C#/PlugIn/Properties/AssemblyInfo.cs <==
﻿//-----------------------------------------------------------------------
// <copyright file="AssemblyInfo.cs" company="Swyx Solutions AG">
//     (c) Swyx Solutions AG
// </copyright>
//-----------------------------------------------------------------------
using System;
using System.Reflection;
using System.Runtime.InteropServices;

// General Information about an assembly is controlled through the following 
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
[assembly: AssemblyTitle("CSharpAddIn")]
[assembly: AssemblyDescription("")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("Swyx Solution AG")]
[assembly: AssemblyProduct("CSharpAddIn")]
[assembly: AssemblyCopyright("Copyright © Swyx Solutions")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]

// Setting ComVisible to false makes the types in this assembly not visible 
// to COM components.  If you need to access a type in this assembly from 
// COM, set the ComVisible attribute to true on that type.
[assembly: ComVisible(false)]

// The following GUID is for the ID of the typelib if this project is exposed to COM
[assembly: Guid("14be4e5a-25a7-4173-bdd9-07c40ccb6ef8")]

// Version information for an assembly consists of the following four values:
//
//      Major Version
//      Minor Version 
//      Build Number
//      Revision
//
// You can specify all the values or you can default the Build and Revision Numbers 
// by using the '*' as shown below:
// [assembly: AssemblyVersion("1.0.*")]
[assembly: AssemblyVersion("11.25.0.0")]
[assembly: AssemblyFileVersion("11.25.0.0")]
[assembly: CLSCompliant(false)]

==> download.php?loc=extern&filen=kb5010_SwyxItClientSDK_11.32.zip: Samples/C#/PlugIn/Properties/AssemblyInfo.cs <==
﻿//-----------------------------------------------------------------------
// <copyright file="AssemblyInfo.cs" company="Swyx Solutions AG">
//     (c) Swyx Solutions AG
// </copyright>
//-----------------------------------------------------------------------
using System;
using System.Reflection;
using System.Runtime.InteropServices;

// General Information about an assembly is controlled through the following 
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
[assembly: AssemblyTitle("CSharpAddIn")]
[assembly: AssemblyDescription("")]
[assembly: AssemblyConfiguration("")]
[assembly: AssemblyCompany("Swyx Solutions")]
[assembly: AssemblyProduct("CSharpAddIn")]
[assembly: AssemblyCopyright("Copyright © Swyx Solutions")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]

// Setting ComVisible to false makes the types in this assembly not visible 
// to COM components.  If you need to access a type in this assembly from 
// COM, set the ComVisible attribute to true on that type.
[assembly: ComVisible(false)]

// The following GUID is for the ID of the typelib if this project is exposed to COM
[assembly: Guid("14be4e5a-25a7-4173-bdd9-07c40ccb6ef8")]

// Version information for an assembly consists of the following four values:
//
//      Major Version
//      Minor Version 
//      Build Number
//      Revision
//
// You can specify all the values or you can default the Build and Revision Numbers 
// by using the '*' as shown below:
// [assembly: AssemblyVersion("1.0.*")]
[assembly: AssemblyVersion("11.32.0.0")]
[assembly: AssemblyFileVersion("11.32.0.0")]
[assembly: CLSCompliant(false)]
